Class: Botiasloop::Config
- Inherits:
-
Anyway::Config
- Object
- Anyway::Config
- Botiasloop::Config
- Defined in:
- lib/botiasloop/config.rb
Class Attribute Summary collapse
Instance Method Summary collapse
-
#active_provider ⇒ Array<String, Hash>
Returns the first configured provider name and its config.
Class Attribute Details
.instance ⇒ Object
12 13 14 |
# File 'lib/botiasloop/config.rb', line 12 def instance @instance ||= new end |
Instance Method Details
#active_provider ⇒ Array<String, Hash>
Returns the first configured provider name and its config
49 50 51 52 53 54 |
# File 'lib/botiasloop/config.rb', line 49 def active_provider providers.each do |name, config| return [name.to_s, config] if provider_configured?(name, config) end ["openrouter", providers["openrouter"]] end |